* 27oct2018
* Sebastian Kripfganz, www.kripfganz.de

/*	Replication file for Section 7 (Empirical application: Distance and FDI) of the article:
	Kripfganz, S., and C. Schwarz.
	Estimation of linear dynamic panel data models with time-invariant regressors.
	Journal of Applied Econometrics.				*/

*==================================================*
version 14.2
clear all
if 0 {												// set to 0 if all community-contributed commands are already installed
	ssc install xtseqreg							// installation of the command xtseqreg
	ssc install xtdpdqml							// installation of the command xtdpdqml
	ssc install xtdpdgmm							// installation of the command xtdpdgmm (undocumented)
	mata: mata mlib index
}
if 0 {												// set to 1 to update existing community-contributed commands
	adoupdate, update
}

*--------------------------------------------------*
*** data set ***
/*	Egger, P., and M. Pfaffermayr (2004).
	Distance, Trade and FDI: A Hausman-Taylor SUR Approach.
	Journal of Applied Econometrics 19, 227-246,
	http://qed.econ.queensu.ca/jae/2004-v19.2/egger-pfaffermayr/		*/
/*	Mayer, T., and S. Zignago (2011).
	Notes on CEPII's distances measures: The GeoDist Database.
	CEPII Working Paper 2011-25,
	http://www.cepii.fr/CEPII/en/publications/wp/abstract.asp?NoDoc=3877		*/
use data.dta

** summary statistics (Tables 29 and 30) **
sum lrfdi ldist lkldist lgdt lkgdt lsimi lrk lrh lrl contig comlang_off comlang_ethno colony
preserve
collapse ldist lkldist lgdt lkgdt lsimi lrk lrh lrl contig comlang_off comlang_ethno colony, by(codeim year)
sum lkldist lgdt lkgdt lsimi lrk lrh lrl
collapse ldist contig comlang_off comlang_ethno colony, by(codeim)
sum ldist contig comlang_off comlang_ethno colony
restore

** variables **
* panel identifier *
egen id = group(codeim ind)
xtset id year

* dependent variable *
gl y			"lrfdi"

* independent variables and instrumental variables *
gl x			"lkldist lgdt lkgdt lsimi lrk lrh lrl"			// time-varying regressors
gl Mx			""
foreach var of glo x {
	by id: egen double M_`var' = mean(`var')					// within-group averages
	gl Mx			"$Mx M_`var'"
}
gl DMx			""
foreach var of glo x {
	gen double DM_`var' = `var' - M_`var'						// deviations from within-group averages
	gl DMx			"$DMx DM_`var'"
}
gl f			"ldist"											// time-invariant regressor
gl ff			"contig comlang_off comlang_other colony"		// additional time-invariant regressors
gl iv			"lsimi lrk lrh"									// original Hausman-Taylor instruments
gl iva			"lsimi lrh"										// alternative Hausman-Taylor instruments
gl ivff			"lsimi lrh contig comlang_off colony"			// alternative Hausman-Taylor instruments with additional time-invariant regressors

* time dummies *
xi, pre(I_) i.year
gl ts			"I_year_1990-I_year_1999"						// static model
gl td			"I_year_1991-I_year_1999"						// dynamic model
gl Mts			""
gl Mtd			""
foreach period of num 1990(1)1999 {
	by id: egen double M_year_`period' = mean(I_year_`period')	// within-group averages
	gl Mts			"$Mts M_year_`period'"
	if `period' > 1990 {
		gl Mtd			"$Mtd M_year_`period'"
	}
}
gl DMts			""
gl DMtd			""
foreach period of num 1990(1)1999 {
	gen double DM_year_`period' = I_year_`period' - M_year_`period'		// deviations from within-group averages
	gl DMts			"$DMts DM_year_`period'"
	if `period' > 1990 {
		gl DMtd			"$DMtd DM_year_`period'"
	}
}

* conditioning variable for marginal effects *
gl xf			"lkldist"							// interaction term
gen lrkl = lrk - lrl
sum lrkl, d
gl ME_p05		= r(p5)								// 5% percentile
gl ME_mean		= r(mean)							// mean
gl ME_p95		= r(p95)							// 95% percentile

*--------------------------------------------------*
*** replication ***
** static FE estimation **
xtreg $y $x $ts , fe								// replication of Egger and Pfaffermayr (2004), Table II (a), Column 4

*--------------------------------------------------*
*** static and dynamic model (Table 4) ***
** static one-stage Hausman-Taylor GMM estimation **
* original Hausman-Taylor instruments *
xtseqreg $y $x $ts $f , two vce(r) iv( $DMx $DMts $iv )
est sto ht1
testparm $ts 										// Wald test for joint insignificance of the time dummies
estat overid
nlcom (_b[ $f ] + _b[ $xf ] * ( $ME_p05 ))			/// marginal effect evaluated at the 5% percentile
	(_b[ $f ] + _b[ $xf ] * ( $ME_mean ))			/// marginal effect evaluated at the mean
	(_b[ $f ] + _b[ $xf ] * ( $ME_p95 ))			// marginal effect evaluated at the 95% percentile
qui predict e if e(sample), e
qui reg L(0/1)D.e, nocons vce(cl id)
test _b[LD.e] = -0.5								// Wooldridge test for serial correlation
drop e

** static two-stage FE-IV estimation **
* original Hausman-Taylor instruments *
qui xtseqreg $y $x $ts , vce(r) nocons iv( $DMx $DMts )		// (first stage)
est sto first
testparm $ts 										// Wald test for joint insignificance of the time dummies
estat overid ht1									// Difference-in-Hansen test
qui predict e if e(sample), e
qui reg L(0/1)D.e, nocons vce(cl id)
test _b[LD.e] = -0.5								// Wooldridge test for serial correlation
drop e
xtseqreg $y ( $x $ts ) $f , f(first, nocons) vce(r) iv( $iv )		// (second stage)
estat overid										// Hansen's J-test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// marginal effect evaluated at the mean
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 ))		// marginal effect evaluated at the 95% percentile

** dynamic one-stage system GMM estimation **
* original Hausman-Taylor instruments *
xtseqreg L(0/1).$y $x $td $f , two vce(r)			///
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	gmm( $y , l(1 1) d c) gmm( $x , l(0 0) d c) iv( $td $iv )		// instruments for the level model
est sto sgmm1
testparm $td 										// Wald test for joint insignificance of the time dummies
estat serial										// Arellano-Bond test
estat overid										// Hansen's J-test
nlcom (_b[ $f ] + _b[ $xf ] * ( $ME_p05 ))			/// short-run marginal effect evaluated at the 5% percentile
	(_b[ $f ] + _b[ $xf ] * ( $ME_mean ))			/// short-run marginal effect evaluated at the mean
	(_b[ $f ] + _b[ $xf ] * ( $ME_p95 ))			/// short-run marginal effect evaluated at the 95% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_p05 )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_mean )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[ $f ] + _b[ $xf ] * ( $ME_p95 )) / (1 - _b[ L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic two-stage system GMM estimation **
* original Hausman-Taylor instruments *
qui xtseqreg L(0/1).$y $x $td , two vce(r)			/// (first stage)
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	gmm( $y , l(1 1) d c) gmm( $x , l(0 0) d c) iv( $td )		// instruments for the level model
testparm $td 										// Wald test for joint insignificance of the time dummies
estat serial										// Arellano-Bond test
estat overid sgmm1									// Difference-in-Hansen test
xtseqreg lrfdi ( L.$y $x $td ) $f , f(, nocons) vce(r) iv( $iv )		// (second stage)
estat overid										// Hansen's J-test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// short-run marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// short-run marginal effect evaluated at the mean
	(_b[_second: $f] + _b[_first: $xf ] * ( $ME_p95 ))		/// short-run marginal effect evaluated at the 95% percentile
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[_second: $f] + _b[_first: $xf ] * ( $ME_mean )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 )) / (1 - _b[_first: L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic one-stage system GMM estimation **
* alternative Hausman-Taylor instruments *
xtseqreg L(0/1).$y $x $td $f , two vce(r)			///
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	gmm( $y , l(1 1) d c) gmm( $x , l(0 0) d c) iv( $td $iva )		// instruments for the level model
est sto sgmm1
testparm $td 										// Wald test for joint insignificance of the time dummies
estat serial										// Arellano-Bond test
estat overid										// Hansen's J-test
nlcom (_b[ $f ] + _b[ $xf ] * ( $ME_p05 ))			/// short-run marginal effect evaluated at the 5% percentile
	(_b[ $f ] + _b[ $xf ] * ( $ME_mean ))			/// short-run marginal effect evaluated at the mean
	(_b[ $f ] + _b[ $xf ] * ( $ME_p95 ))			/// short-run marginal effect evaluated at the 95% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_p05 )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_mean )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[ $f ] + _b[ $xf ] * ( $ME_p95 )) / (1 - _b[ L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic two-stage system GMM estimation **
* alternative Hausman-Taylor instruments *
qui xtseqreg L(0/1).$y $x $td , two vce(r)			/// (first stage)
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	gmm( $y , l(1 1) d c) gmm( $x , l(0 0) d c) iv( $td )		// instruments for the level model
testparm $td 										// Wald test for joint insignificance of the time dummies
estat serial										// Arellano-Bond test
estat overid sgmm1									// Difference-in-Hansen test
xtseqreg lrfdi ( L.$y $x $td ) $f , f(, nocons) vce(r) iv( $iva )		// (second stage)
estat overid										// Hansen's J-test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// short-run marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// short-run marginal effect evaluated at the mean
	(_b[_second: $f] + _b[_first: $xf ] * ( $ME_p95 ))		/// short-run marginal effect evaluated at the 95% percentile
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[_second: $f] + _b[_first: $xf ] * ( $ME_mean )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 )) / (1 - _b[_first: L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic two-stage QML estimation **
* alternative Hausman-Taylor instruments *
qui xtdpdqml $y $x $td , mlp conc initi(2) vce(r)		// (first stage)
testparm D.( $td ) , eq(_model)						// Wald test for joint insignificance of the time dummies
xtseqreg lrfdi ( L.$y $x $td ) $f , vce(r) iv( $iva )		// (second stage)
estat overid										// Hansen's J-test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// short-run marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// short-run marginal effect evaluated at the mean
	(_b[_second: $f] + _b[_first: $xf ] * ( $ME_p95 ))		/// short-run marginal effect evaluated at the 95% percentile
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[_second: $f] + _b[_first: $xf ] * ( $ME_mean )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 )) / (1 - _b[_first: L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

*--------------------------------------------------*
*** robustness checks (Table 5) ***
** static one-stage Hausman-Taylor GMM estimation **
* Hausman-Taylor instruments *
xtseqreg $y $x $ts $f $ff , two vce(r) iv( $DMx $DMts $f $ivff )
est sto ht1
testparm $ts 										// Wald test for joint insignificance of the time dummies
estat overid
nlcom (_b[ $f ] + _b[ $xf ] * ( $ME_p05 ))			/// marginal effect evaluated at the 5% percentile
	(_b[ $f ] + _b[ $xf ] * ( $ME_mean ))			/// marginal effect evaluated at the mean
	(_b[ $f ] + _b[ $xf ] * ( $ME_p95 ))			// marginal effect evaluated at the 95% percentile
qui predict e if e(sample), e
qui reg L(0/1)D.e, nocons vce(cl id)
test _b[LD.e] = -0.5								// Wooldridge test for serial correlation
drop e

** static two-stage FE-IV estimation **
* Hausman-Taylor instruments *
qui xtseqreg $y $x $ts , vce(r) nocons iv( $DMx $DMts )		// (first stage)
est sto first
testparm $ts 										// Wald test for joint insignificance of the time dummies
estat overid ht1									// Difference-in-Hansen test
estat hausman ht1 ( $x )							// generalized Hausman test
qui predict e if e(sample), e
qui reg L(0/1)D.e, nocons vce(cl id)
test _b[LD.e] = -0.5								// Wooldridge test for serial correlation
drop e
xtseqreg $y ( $x $ts ) $f $ff , f(first, nocons) vce(r) iv( $f $ivff )		// (second stage)
estat overid										// Hansen's J-test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// marginal effect evaluated at the mean
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 ))		// marginal effect evaluated at the 95% percentile

** dynamic one-stage system GMM estimation **
* Hausman-Taylor instruments *
xtseqreg L(0/1).$y $x $td $f $ff , two vce(r)			///
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	gmm( $y , l(1 1) d c) gmm( $x , l(0 0) d c) iv( $td $f $ivff )		// instruments for the level model
est sto sgmm1
testparm $td 										// Wald test for joint insignificance of the time dummies
estat serial										// Arellano-Bond test
estat overid										// Hansen's J-test
nlcom (_b[ $f ] + _b[ $xf ] * ( $ME_p05 ))			/// short-run marginal effect evaluated at the 5% percentile
	(_b[ $f ] + _b[ $xf ] * ( $ME_mean ))			/// short-run marginal effect evaluated at the mean
	(_b[ $f ] + _b[ $xf ] * ( $ME_p95 ))			/// short-run marginal effect evaluated at the 95% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_p05 )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_mean )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[ $f ] + _b[ $xf ] * ( $ME_p95 )) / (1 - _b[ L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic two-stage system GMM estimation **
* Hausman-Taylor instruments *
qui xtseqreg L(0/1).$y $x $td , two vce(r)			/// (first stage)
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	gmm( $y , l(1 1) d c) gmm( $x , l(0 0) d c) iv( $td )		// instruments for the level model
testparm $td 										// Wald test for joint insignificance of the time dummies
estat serial										// Arellano-Bond test
estat overid sgmm1									// Difference-in-Hansen test
xtseqreg lrfdi ( L.$y $x $td ) $f $ff , f(, nocons) vce(r) iv( $f $ivff )		// (second stage)
estat overid										// Hansen's J-test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// short-run marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// short-run marginal effect evaluated at the mean
	(_b[_second: $f] + _b[_first: $xf ] * ( $ME_p95 ))		/// short-run marginal effect evaluated at the 95% percentile
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[_second: $f] + _b[_first: $xf ] * ( $ME_mean )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 )) / (1 - _b[_first: L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic two-stage QML estimation **
* Hausman-Taylor instruments *
qui xtdpdqml $y $x $td , mlp conc initi(2) vce(r)		// (first stage)
testparm D.( $td ) , eq(_model)						// Wald test for joint insignificance of the time dummies
xtseqreg lrfdi ( L.$y $x $td ) $f $ff , vce(r) iv( $f $ivff )		// (second stage)
estat overid										// Hansen's J-test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// short-run marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// short-run marginal effect evaluated at the mean
	(_b[_second: $f] + _b[_first: $xf ] * ( $ME_p95 ))		/// short-run marginal effect evaluated at the 95% percentile
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[_second: $f] + _b[_first: $xf ] * ( $ME_mean )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 )) / (1 - _b[_first: L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** static one-stage CRE estimation **
* Mundlak projection *
xtreg $y $x $ts $Mx $Mts $f $ff , re vce(r)
testparm $ts 										// Wald test for joint insignificance of the time dummies
testparm $Mx 										// Mundlak test
nlcom (_b[ $f ] + _b[ $xf ] * ( $ME_p05 ))			/// marginal effect evaluated at the 5% percentile
	(_b[ $f ] + _b[ $xf ] * ( $ME_mean ))			/// marginal effect evaluated at the mean
	(_b[ $f ] + _b[ $xf ] * ( $ME_p95 ))			// marginal effect evaluated at the 95% percentile
qui predict e if e(sample), e
qui reg L(0/1)D.e, nocons vce(cl id)
test _b[LD.e] = -0.5								// Wooldridge test for serial correlation
drop e

** dynamic one-stage system GMM estimation **
* Mundlak projection *
xtseqreg L(0/1).$y $x $Mx $td $Mtd $f $ff , two vce(r)		///
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	gmm( $y , l(1 1) d c) gmm( $x , l(0 0) d c) iv( $Mx $td $Mtd $f $ff )		// instruments for the level model
testparm $td 										// Wald test for joint insignificance of the time dummies
testparm $Mx 										// Mundlak test
estat serial										// Arellano-Bond test
estat overid										// Hansen's J-test
nlcom (_b[ $f ] + _b[ $xf ] * ( $ME_p05 ))			/// short-run marginal effect evaluated at the 5% percentile
	(_b[ $f ] + _b[ $xf ] * ( $ME_mean ))			/// short-run marginal effect evaluated at the mean
	(_b[ $f ] + _b[ $xf ] * ( $ME_p95 ))			/// short-run marginal effect evaluated at the 95% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_p05 )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_mean )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[ $f ] + _b[ $xf ] * ( $ME_p95 )) / (1 - _b[ L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

*--------------------------------------------------*
*** additional estimates (Table 31) ***
** dynamic one-stage nonlinear GMM estimation **
* Hausman-Taylor instruments *
xtdpdgmm L(0/1).$y $x $td $f , noser two vce(r)		///
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	iv( $td $iva )									// instruments for the level model
est sto nlgmm1
testparm $td 										// Wald test for joint insignificance of the time dummies
estat serial										// Arellano-Bond test
estat overid										// Hansen's J-test
nlcom (_b[ $f ] + _b[ $xf ] * ( $ME_p05 ))			/// short-run marginal effect evaluated at the 5% percentile
	(_b[ $f ] + _b[ $xf ] * ( $ME_mean ))			/// short-run marginal effect evaluated at the mean
	(_b[ $f ] + _b[ $xf ] * ( $ME_p95 ))			/// short-run marginal effect evaluated at the 95% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_p05 )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_mean )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[ $f ] + _b[ $xf ] * ( $ME_p95 )) / (1 - _b[ L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic two-stage nonlinear GMM estimation **
* Hausman-Taylor instruments *
qui xtdpdgmm L(0/1).$y $x $td , noser two vce(r)		/// (for the Wald test only)
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	iv( $td )										// instruments for the level model
testparm $td 										// Wald test for joint insignificance of the time dummies
qui xtdpdgmm L(0/1).$y $x $td , noser two aux vce(r)		/// (first stage)
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	iv( $td )										// instruments for the level model
estat serial										// Arellano-Bond test
estat overid										// Hansen's J-test
estat overid nlgmm1									// Difference-in-Hansen test
xtseqreg lrfdi ( L.$y $x $td ) $f , f(, copy) vce(r) iv( $iva )		// (second stage)
estat overid										// Hansen's J-test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// short-run marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// short-run marginal effect evaluated at the mean
	(_b[_second: $f] + _b[_first: $xf ] * ( $ME_p95 ))		/// short-run marginal effect evaluated at the 95% percentile
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[_second: $f] + _b[_first: $xf ] * ( $ME_mean )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 )) / (1 - _b[_first: L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic two-stage system GMM estimation **
* second-stage Mundlak projection *
qui xtseqreg L(0/1).$y $x $td , two vce(r)			/// (first stage)
	gmm( $y , l(2 6) c m(d)) gmm( $x , l(0 4) c m(d))		/// instruments for the first-differenced model
	gmm( $y , l(1 1) d c) gmm( $x, l(0 0) d c) iv( $td )		// instruments for the level model
testparm $td 										// Wald test for joint insignificance of the time dummies
estat serial										// Arellano-Bond test
xtseqreg lrfdi ( L.$y $x $td ) $Mx $Mtd $f $ff , f(, nocons) vce(r)		// (second stage)
testparm $Mx , eq(_second)							// Mundlak test
estat overid										// Hansen's J-test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// short-run marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// short-run marginal effect evaluated at the mean
	(_b[_second: $f] + _b[_first: $xf ] * ( $ME_p95 ))		/// short-run marginal effect evaluated at the 95% percentile
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[_second: $f] + _b[_first: $xf ] * ( $ME_mean )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 )) / (1 - _b[_first: L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic one-stage QML estimation **
* Mundlak projection *
xtdpdqml $y $x $Mx $td $Mtd $f $ff , re initval(0.05 0.15 3 0.05) vce(r) pro( $x $td $Mtd , omit) pro( $Mx $f $ff , l(0))
testparm $td 										// Wald test for joint insignificance of the time dummies
testparm $Mx 										// Mundlak test
nlcom (_b[ $f ] + _b[ $xf ] * ( $ME_p05 ))			/// short-run marginal effect evaluated at the 5% percentile
	(_b[ $f ] + _b[ $xf ] * ( $ME_mean ))			/// short-run marginal effect evaluated at the mean
	(_b[ $f ] + _b[ $xf ] * ( $ME_p95 ))			/// short-run marginal effect evaluated at the 95% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_p05 )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[ $f ] + _b[ $xf ] * ( $ME_mean )) / (1 - _b[ L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[ $f ] + _b[ $xf ] * ( $ME_p95 )) / (1 - _b[ L.$y ]))		// long-run marginal effect evaluated at the 95% percentile

** dynamic two-stage QML estimation **
* second-stage Mundlak projection *
qui xtdpdqml $y $x $td , mlp conc initi(2) vce(r)		// (first stage)
testparm D.( $td ) , eq(_model)						// Wald test for joint insignificance of the time dummies
xtseqreg lrfdi ( L.$y $x $td ) $Mx $Mtd $f $ff , vce(r)
testparm $Mx , eq(_second)							// Mundlak test
nlcom (_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 ))		/// short-run marginal effect evaluated at the 5% percentile
	(_b[_second: $f ] + _b[_first: $xf ] * ( $ME_mean ))		/// short-run marginal effect evaluated at the mean
	(_b[_second: $f] + _b[_first: $xf ] * ( $ME_p95 ))		/// short-run marginal effect evaluated at the 95% percentile
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p05 )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the 5% percentile
	((_b[_second: $f] + _b[_first: $xf ] * ( $ME_mean )) / (1 - _b[_first: L.$y ]))		/// long-run marginal effect evaluated at the mean
	((_b[_second: $f ] + _b[_first: $xf ] * ( $ME_p95 )) / (1 - _b[_first: L.$y ]))		// long-run marginal effect evaluated at the 95% percentile
